Multivariate continuous data, generated as five clusters with an AR(1) correlation structure determining the common covariance matrix for each observation.
p18_corr_mvn_1p18_corr_mvn_2
p18_corr_mvn_3
An object of class matrix (inherits from array) with 100 rows and 18 columns.
An object of class matrix (inherits from array) with 100 rows and 18 columns.
An object of class matrix (inherits from array) with 100 rows and 18 columns.